@@ -24,8 +24,8 @@
 # DRIVER_OPTION_CCID_EXCHANGE_AUTHORIZED bit in the ifdDriverOptions
 # option of the CCID driver Info.plist file
 
+from smartcard.pcsc.PCSCPart10 import SCARD_SHARE_DIRECT, getTlvProperties
 from smartcard.System import readers
-from smartcard.pcsc.PCSCPart10 import getTlvProperties, SCARD_SHARE_DIRECT
 
 # for each reader
 for reader in readers():
@@ -43,6 +43,6 @@ for reader in readers():
             "PCSCv2_PART10_PROPERTY_wIdProduct",
             "PCSCv2_PART10_PROPERTY_wIdVendor",
         ]:
-            print("%s: 0x%04X" % (key, tlv[key]))
+            print(f"{key}: 0x{tlv[key]:04X}")
         else:
-            print("%s: %s" % (key, tlv[key]))
+            print(f"{key}: {tlv[key]}")
