@@ -18,18 +18,15 @@
 #   You should have received a copy of the GNU General Public License along
 #   with this program; if not, see <http://www.gnu.org/licenses/>.
 
-from smartcard.System import readers
-from smartcard.pcsc.PCSCPart10 import (
-    SCARD_SHARE_DIRECT,
-    SCARD_LEAVE_CARD,
-    SCARD_CTL_CODE,
-)
 from smartcard.Exceptions import SmartcardException
+from smartcard.pcsc.PCSCPart10 import SCARD_CTL_CODE
+from smartcard.scard import SCARD_LEAVE_CARD, SCARD_SHARE_DIRECT
+from smartcard.System import readers
 
 IOCTL_SMARTCARD_VENDOR_IFD_EXCHANGE = SCARD_CTL_CODE(1)
 
 
-def switch_interface(interface):
+def switch_interface(my_interface):
     """
     switch from contact to contactless (or reverse) on a GemProx DU reader
     """
@@ -37,14 +34,14 @@ def switch_interface(interface):
         cardConnection = reader.createConnection()
         cardConnection.connect(mode=SCARD_SHARE_DIRECT, disposition=SCARD_LEAVE_CARD)
 
-        switch_interface_cmd = [0x52, 0xF8, 0x04, 0x01, 0x00, interface]
+        switch_interface_cmd = [0x52, 0xF8, 0x04, 0x01, 0x00, my_interface]
         print("Reader:", reader, "=>", end=" ")
         try:
             res = cardConnection.control(
                 IOCTL_SMARTCARD_VENDOR_IFD_EXCHANGE, switch_interface_cmd
             )
         except SmartcardException as e:
-            print("FAILED")
+            print("FAILED", e)
         else:
             if res != [0, 0, 0, 0]:
                 print("Failed: ", end="")
@@ -64,7 +61,6 @@ if __name__ == "__main__":
 
     # 01h = Switch to contactless interface
     # 02h = Switch to contact interface
-
     # switch to contactless by default
     interface = 0x01
     if len(sys.argv) > 1:
